package com.dcsoft.system.kq.service;

import java.text.ParseException;
import java.util.List;
import com.dcsoft.system.kq.domain.KqGatherMonth;

/**
 * 月汇总Service接口
 *
 * @author dcsoft
 * @date 2023-08-01
 */
public interface IKqGatherMonthService
{
    /**
     * 查询月汇总
     *
     * @param id 月汇总主键
     * @return 月汇总
     */
    public KqGatherMonth selectKqGatherMonthById(Long id);

    /**
     * 查询月汇总列表
     *
     * @param kqGatherMonth 月汇总
     * @return 月汇总集合
     */
    public List<KqGatherMonth> selectKqGatherMonthList(KqGatherMonth kqGatherMonth) throws ParseException;

    /**
     * 新增月汇总
     *
     * @param kqGatherMonth 月汇总
     * @return 结果
     */
    public int insertKqGatherMonth(KqGatherMonth kqGatherMonth);

    /**
     * 修改月汇总
     *
     * @param kqGatherMonth 月汇总
     * @return 结果
     */
    public int updateKqGatherMonth(KqGatherMonth kqGatherMonth);

    /**
     * 批量删除月汇总
     *
     * @param ids 需要删除的月汇总主键集合
     * @return 结果
     */
    public int deleteKqGatherMonthByIds(Long[] ids);

    /**
     * 删除月汇总信息
     *
     * @param id 月汇总主键
     * @return 结果
     */
    public int deleteKqGatherMonthById(Long id);

    public int createKqGatherMonth(KqGatherMonth kqGatherMonth);

    public int createKqGather();

}
